import pandas as pd
import math
import csv

# Read data from CSV file
data = pd.read_csv('10_Polyphen2_HDIV_pred_final.csv')

# Initialize counters
TP = 0
TN = 0
FP = 0
FN = 0
path_unk = 0
neutral_unk = 0

# Iterate through data to calculate TP, TN, FP, FN, path_unk, and neutral_unk
for index, row in data.iterrows():
    label = row['labels']
    prediction = row['Polyphen2_HDIV_pred']

    if prediction not in ['P', 'B']:  # A means Ambigious sort of UVSes
        if label == 'P':
            path_unk += 1
        elif label == 'B':
            neutral_unk += 1
    else:
        if label == 'P' and prediction == 'P': # D-Damaging (Pathogenic) - T-Tolerance (Benign)
            TP += 1
        elif label == 'P' and prediction == 'B':
            FN += 1
        elif label == 'B' and prediction == 'B':
            TN += 1
        elif label == 'B' and prediction == 'P':
            FP += 1

# Calculate performance metrics
accuracy = round((TP + TN) / (TP + TN + FP + FN), 3) if (TP + TN + FP + FN) > 0 else 0
mcc = round(((TP * TN - FP * FN) / math.sqrt((TP + FP) * (TP + FN) * (TN + FP) * (TN + FN))), 3) if (TP + FP) * (
            TP + FN) * (TN + FP) * (TN + FN) > 0 else 0
ppv = round(TP / (TP + FP), 3) if (TP + FP) > 0 else 0
npv = round(TN / (TN + FN), 3) if (TN + FN) > 0 else 0
sen = round(TP / (TP + FN), 3) if (TP + FN) > 0 else 0
spec = round(TN / (FP + TN), 3) if (FP + TN) > 0 else 0
nMCC = round((1 + mcc) / 2, 3)
opm = round((ppv + npv) * (sen + spec) * (accuracy + nMCC) / 8, 3)

# Total classified and coverage
classified = TP + TN + FP + FN
total = TP + TN + FP + FN + path_unk + neutral_unk
coverage = round((classified / total), 3) if total > 0 else 0

# Define the output file path
output_file = '10_Polyphen2_HDIV_performance_metrics.csv'

# Write metrics to CSV file
with open(output_file, 'w', newline='') as csvfile:
    csv_writer = csv.writer(csvfile)
    csv_writer.writerow(["Metric", "Value"])
    csv_writer.writerow(["Accuracy", accuracy])
    csv_writer.writerow(["MCC", mcc])
    csv_writer.writerow(["nMCC", nMCC])
    csv_writer.writerow(["PPV", ppv])
    csv_writer.writerow(["NPV", npv])
    csv_writer.writerow(["Sensitivity", sen])
    csv_writer.writerow(["Specificity", spec])
    csv_writer.writerow(["OPM", opm])
    csv_writer.writerow(["Pathogenic as unknown", path_unk])
    csv_writer.writerow(["Neutral as unknown", neutral_unk])
    csv_writer.writerow(["True Positives (TP)", TP])
    csv_writer.writerow(["True Negatives (TN)", TN])
    csv_writer.writerow(["False Positives (FP)", FP])
    csv_writer.writerow(["False Negatives (FN)", FN])
    csv_writer.writerow(["Coverage", coverage])

print(f"Performance metrics have been written to {output_file}.")
