import pandas as pd

# Define paths
wd = "/home/kabir/Desktop/PON-P3/"

# Load merged DataFrame
data_file = pd.read_csv('REVEL_pred_dbNSFP.txt', delimiter='\t')

# Drop rows where REVEL_score is "."
data_file = data_file[data_file['REVEL_score'] != '.']

# Create a list to store all the records
records = []

# Iterate through the DataFrame rows and store the records
for i, row in data_file.iterrows():
    g_variations = f"{row['ref']}{row['pos']}{row['alt']}"

    revel_score = float(row['REVEL_score'])
    if revel_score >= 0.38:
        pred = 'P'
    else:
        pred = 'B'

    record = {
        'chr': row['chr'],
        'g_variations': g_variations,
        'Ensembl_transcriptid': row['Ensembl_transcriptid'],
        'REVEL_pred': pred
    }
    records.append(record)

# Create a new DataFrame from the records
new_df = pd.DataFrame(records)

ponp3_testing_data = pd.read_csv(wd+'update3/dataset/file_for_dbNSFP/merged_ponp3_df_with_ensembl_transcript.csv')

# Merge new_df with ponp3_testing_data on g_variations and Ensembl_transcriptid
merged_df = pd.merge(new_df, ponp3_testing_data, how='inner', left_on=['g_variations', 'Ensembl_transcriptid'], right_on=['g_variations', 'Ensemble_transcript'])

# Select specific columns from merged DataFrame
selected_columns = ['refseq_ids', 'p_variations', 'g_variations', 'labels','REVEL_pred']
filtered_df = merged_df[selected_columns]

# Display the filtered DataFrame
print(filtered_df.head())

# Save the filtered DataFrame to a CSV file if needed
filtered_df.to_csv(f'20_REVEL_pred_final.csv', index=False)